# Tutorials Overview

This section hosts guided, assignment-style tutorials for practical usage and extension
of `nomad-simulations`.

## Available Tutorials

## [Stand-alone Usage](standalone_schema_tutorial.md)

Assignment-style tutorial for standalone schema usage without parser-plugin complexity.
